Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(876)

Unified Diff: third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h

Issue 2290233007: Move convertViewportToWindow and convertWindowToViewport from (Closed)
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h
diff --git a/third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h b/third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h
index 0d38fa2b3fdfe3c2486101fb8b503c8255e4953e..3865677eb4ffce7b513a4e4369ca4ed4e91504ca 100644
--- a/third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h
+++ b/third_party/WebKit/Source/web/WebEmbeddedWorkerImpl.h
@@ -46,6 +46,7 @@ namespace blink {
class ParentFrameTaskRunners;
class ServiceWorkerGlobalScopeProxy;
class WebLocalFrameImpl;
+class WebFrameWidget;
class WebServiceWorkerNetworkProvider;
class WebView;
class WorkerInspectorProxy;
@@ -117,10 +118,11 @@ private:
Persistent<WorkerInspectorProxy> m_workerInspectorProxy;
// 'shadow page' - created to proxy loading requests from the worker.
// Both WebView and WebFrame objects are close()'ed (where they're
// deref'ed) when this EmbeddedWorkerImpl is destructed, therefore they
// are guaranteed to exist while this object is around.
WebView* m_webView;
+ WebFrameWidget* m_webFrameWidget;
Persistent<WebLocalFrameImpl> m_mainFrame;
bool m_loadingShadowPage;
@@ -117,10 +118,11 @@ private:
Persistent<WorkerInspectorProxy> m_workerInspectorProxy;
// 'shadow page' - created to proxy loading requests from the worker.
- // Both WebView and WebFrame objects are close()'ed (where they're
- // deref'ed) when this EmbeddedWorkerImpl is destructed, therefore they
- // are guaranteed to exist while this object is around.
+ // WebView, WebFrameWidget and WebFrame objects are close()'ed (where
+ // they're deref'ed) when this EmbeddedWorkerImpl is destructed, therefore
+ // they are guaranteed to exist while this object is around.
WebView* m_webView;

Powered by Google App Engine
This is Rietveld 408576698